@@ -55,6 +55,7 @@ add_new_window(GSH * gsh)
 	$(gsh, add.window);
 	gsh->rows->current=1;
 	$(gsh, init);
+	GSH_SET(GSH_IN_SECONDARY_WIN);
 }
 
 static void
@@ -164,7 +165,17 @@ gsh_handle_add_arguments(GSH * gsh, const gint argc, const gchar **argv,
 		gsh_text_editor(gsh, argv[*counter]);
 		break;
 
-	case 'l':
+	case 'f': /* Add a form with check boxes or radio buttons.  */
+		GSH_COUNT(argc, counter);
+		gsh_add_form(gsh, argv[(*counter)]);
+		break;
+
+	case 'L': /* Add a list.  */
+		GSH_COUNT(argc, counter);
+		$(gsh, manage, gsh_tree_view_new(gsh, argv[*counter]));
+		break;
+
+	case 'l': /* Add a label.  */
 		GSH_COUNT(argc, counter);
 		$(gsh, add.label, argv[(*counter)]);
 		break;
