@@ -63,10 +63,9 @@ setup_callback(struct GSH * gsh, GtkWidget * button, const gchar * command)
 static void
 create_button(struct GSH * gsh)
 {
-	if(!GTK_IS_MENU(gsh->rows->v) && !GTK_IS_MENU_BAR(gsh->rows->v))
-		gsh->widgets.button=gtk_button_new();
-	else
-		gtk_widget_show(gsh->widgets.button=gtk_menu_item_new());
+	gtk_widget_show(gsh->widgets.button=(!GTK_IS_MENU(gsh->rows->v) 
+		&& !GTK_IS_MENU_BAR(gsh->rows->v))
+		? gtk_button_new() : gtk_menu_item_new());
 }
 
 static void
@@ -79,38 +78,24 @@ common_button_setup(GSH * gsh, GtkWidget * button, const gchar * command)
 static GtkWidget *
 label_to_icon_translation(const gchar * label)
 {
-	GtkWidget * image;
-	gchar * cut_label;
+	GtkWidget * image=NULL;
+	struct
+	{
+		const gchar * label;
+		const gchar * icon;
+	} mapping[] = GSH_LABEL_TO_ICON_MAPPINGS;
+	const guint mapping_size=sizeof(mapping)/sizeof(mapping[0]);
+	guint mapping_count;
 
-	cut_label=(gchar *)label;
-	g_strstrip(cut_label);
-#define MATCHES(text) !strcmp(text, cut_label)
-#define ICON(id)\
-	gtk_widget_show(image=gtk_image_new_from_stock(GTK_STOCK_##id, \
-		GTK_ICON_SIZE_SMALL_TOOLBAR))
+	for(mapping_count=0; mapping_count < mapping_size; mapping_count++)
+		if(!strcmp(mapping[mapping_count].label, 
+			g_strstrip((gchar*)label)))
+			gtk_widget_show(image=gtk_image_new_from_stock(
+				mapping[mapping_count].icon, 
+				GTK_ICON_SIZE_SMALL_TOOLBAR));
 
-	if(MATCHES("Exit"))
-		ICON(QUIT);
-	else if(MATCHES("About"))
-		ICON(ABOUT);
-	else if(MATCHES("Open..."))
-		ICON(OPEN);
-	else if(MATCHES("Save"))
-		ICON(SAVE);
-	else if(MATCHES("Save As..."))
-		ICON(SAVE_AS);
-	else if(MATCHES("Cut"))
-		ICON(CUT);
-	else if(MATCHES("Copy"))
-		ICON(COPY);
-	else if(MATCHES("Paste"))
-		ICON(PASTE);
-	else if(MATCHES("Close"))
-		ICON(CLOSE);
-	else
-		ICON(EXECUTE);
-
-	return image;
+	return image ? image : gtk_image_new_from_stock(
+		GTK_STOCK_EXECUTE, GTK_ICON_SIZE_SMALL_TOOLBAR);
 }
 
 static void
