@@ -26,4 +26,17 @@
 GtkWidget *
 gsh_add_button(struct GSH * gsh, const gchar * string);
 
+#define GSH_LABEL_TO_ICON_MAPPINGS \
+{\
+	{ "Run...", GTK_STOCK_EXECUTE },\
+	{ "About", GTK_STOCK_ABOUT },\
+	{ "Exit", GTK_STOCK_QUIT },\
+	{ "Save", GTK_STOCK_SAVE },\
+	{ "Save As...", GTK_STOCK_SAVE_AS },\
+	{ "Cut", GTK_STOCK_CUT },\
+	{ "Copy", GTK_STOCK_COPY },\
+	{ "Paste", GTK_STOCK_PASTE },\
+	{ "Close", GTK_STOCK_CLOSE }\
+}
+
 #endif
