@@ -107,7 +107,9 @@ setup_main_member_fields(GSH * gsh)
 {
 	gsh->geometry = (gchar *)NULL;
 	gsh->bflags = 0;
+#ifdef USE_GTK
 	gsh->icon_size=GTK_ICON_SIZE_DND;
+#endif /* USE_GTK */
 }
 
 static void
@@ -139,3 +141,16 @@ gsh_new_GSH()
 	return gsh;
 }
 
+void
+gsh_widget_set_color(GtkWidget * widget, 
+	const gchar * color_string, gboolean fg_color)
+{
+	GdkColor color;
+
+	gdk_color_parse(color_string, &color);
+	if(fg_color)
+		gtk_widget_modify_fg(widget, GTK_STATE_NORMAL, &color);
+	else
+		gtk_widget_modify_bg(widget, GTK_STATE_NORMAL, &color);
+}
+
