@@ -35,10 +35,6 @@
 #include <unistd.h>
 #include <signal.h>
 
-#ifdef LIBGC
-#include <gc.h>
-#endif /* LIBGC */
-
 #include "../libantiright/library.h"
 
 #ifndef YYFILE
@@ -69,7 +65,7 @@ struct GSH
 		GtkWidget * last_managed;
 		struct /* app mode */
 		{
-			struct
+			struct /* menus */
 			{
 				GtkWidget * file;
 				GtkWidget * edit;
@@ -119,4 +115,8 @@ typedef struct GSH GSH;
 struct GSH *
 gsh_new_GSH();
 
+void
+gsh_widget_set_color(GtkWidget * widget, 
+	const gchar * color_string, gboolean fg_color);
+
 #endif
