@@ -111,6 +111,10 @@ gsh_handle_switch_arguments(GSH * gsh, const gint argc, const gchar **argv,
 		break;
 	case 't': /* test area.  */
 		{
+			GtkWidget * parent;
+			parent=gtk_event_box_new();
+			gsh_swallow_app(parent, "internal");
+			$(gsh, manage, parent);
 		}
 		break;
 	default:
