@@ -25,10 +25,21 @@
 
 #include "gtkshell.h"
 
-void
-     gsh_count(int argc, int *counter);
+#ifdef DEBUG
+#define GSH_COUNT(argc, counter) \
+{\
+	(*counter)++;\
+	g_assert((*counter) <= argc);\
+}
+#else /* not DEBUG */
+#define GSH_COUNT(argc, counter) \
+{\
+	(*counter)++;\
+}
+#endif /* DEBUG */
 
 void
-     gsh_handle_switch_arguments(struct GSH * gsh, int argc, char **argv, int *counter);
+gsh_handle_switch_arguments(GSH * gsh, const gint argc, const gchar **argv, 
+	gint *counter);
 
-#endif
+#endif /* not GSH_OPTIONS_H */
