@@ -38,15 +38,15 @@
 static void
 set_vte_specific_terminal_options(struct GSH_Terminal * term)
 {
+	GSH * gsh;
+
+	gsh=term->gsh;
 	VSETW(size, term->dimensions.width, term->dimensions.height);
 	VSETW(allow_bold, TRUE);
 	VSETW(backspace_binding, VTE_ERASE_ASCII_BACKSPACE);
-	if(term->transparent)
+	if(GSH_FLAG(GSH_TERM_TRANSPARENT))
 	{
-		/* Only the first terminal should be transparent,
-		   to save memory.  */
 		VSETW(background_transparent, TRUE);
-		term->transparent=FALSE;
 	}
 }
 #endif /* HAVE_VTE */
@@ -207,7 +207,6 @@ initialize_fields(struct GSH_Terminal * term)
 	term->font=NULL;
 	term->dimensions.width=80;
 	term->dimensions.height=24;
-	term->transparent=TRUE;
 }
 
 static void
