@@ -174,37 +174,47 @@ get_text(GtkWidget * editor)
 	return gtk_text_buffer_get_text(buffer, &start, &end, TRUE);
 }
 
+static void
+save_to_opened_file(GSH * gsh)
+{
+	gchar * text;
+
+	text=get_text(gsh->editor.widget);
+	AR_TEXT_TO_FILE(gsh->editor.filename, text);
+	g_free(text);
+}
+
 void
 gsh_editor_save(struct GSH * gsh)
 {
 	TEST_EDITOR_EXISTS(gsh);
 	/* Choose action based on whether or not file has been chosen.*/
 	if(gsh->editor.filename)
-	{
-		gchar * text;
-
-		text=get_text(gsh->editor.widget);
-		AR_TEXT_TO_FILE(gsh->editor.filename, text);
-		g_free(text);
-	}
+		save_to_opened_file(gsh);
 	else
 		gsh_editor_save_as(gsh);
 }
 
 #define PROMPT_FILENAME() antiright_pipe_read("gtkshell -df")
+#define FILENAME_NOT_EMPTY strcmp(gsh->editor.filename, "")
 
 static void
 get_filename(struct GSH * gsh)
 {
+	gchar * tmp_filename;
+
 	/* Make sure that FILENAME is freed if previously used.  */
 	if(gsh->editor.filename)
 		g_free(gsh->editor.filename);
 	/* Get the filename.  */
+	tmp_filename=gsh->editor.filename;
 	gsh->editor.filename=PROMPT_FILENAME();
+	/* Restore filename if empty, in case of open file, so that
+	   file will not have to be reopened/reselected on save.  */
+	if(!FILENAME_NOT_EMPTY)
+		gsh->editor.filename=tmp_filename;
 }
 
-#define FILENAME_NOT_EMPTY strcmp(gsh->editor.filename, "")
-
 void
 gsh_editor_save_as(struct GSH * gsh)
 {
