@@ -32,6 +32,7 @@ gsh_delete_GSHUpdatedWidget(struct GSHUpdatedWidget * item)
 static void
 gsh_GSHUpdatedWidget_update(struct GSHUpdatedWidget * item)
 {
+	/* Call function pointer specific to the updater type.  */
 	item->function(item->command, item->widget);
 }
 
@@ -53,7 +54,7 @@ gsh_new_GSHUpdatedWidget(void (*function)(const gchar *, gpointer),
 	/* Assign widget-specific update information, specifically
 	 * the widget command, a pointer to the widget, and the widget's
 	 * updater function.  */
-	updater->command=g_strdup(command);
+	updater->command=(gchar *)command;
 	updater->widget=widget;
 	updater->function=function;
 
