@@ -60,18 +60,15 @@ gsh_update_label(const gchar *command, gpointer widget)
 void
 gsh_add_updated_label(struct GSH * gsh, const gchar *command)
 {
-#define GWA gsh->widgets.app
-	GtkWidget * status = GWA.status;
-#ifdef DEBUG
-	g_message("gsh_add_updated_label()");
-	ARPASSERT(gsh);
-	ARPASSERT(command);
-#endif /* DEBUG */
-	$(gsh->update, add, ARNEW(gsh, GSHUpdatedWidget, &gsh_update_label, 
-		command, (GSH_FLAG(GSH_APP_MODE) && status)
-		? status : gsh_add_label(gsh, (char *)command)));
+	GtkWidget * update_target;
+
+#define GSH_STATUS_WIDGET gsh->widgets.app.status
+	if(!(GSH_FLAG(GSH_APP_MODE) && (update_target=GSH_STATUS_WIDGET)))
+		update_target=gsh_add_label(gsh, (char *) command);
+	GSH_NEW_UPDATER_WITH_COMMAND(gsh, gsh_update_label, 
+		update_target, command);
 	GSH_UNSET(GSH_APP_MODE);
 	/* Prevent two updaters from being 
 	   assigned to the status bar label.  */
-	GWA.status=NULL;
+	GSH_STATUS_WIDGET=NULL;
 }
