@@ -40,4 +40,8 @@
 
 #include "macros.h"
 
+#ifdef LIBGC
+#include <gc/gc.h>
+#endif /* LIBGC */
+
 #endif				/* LIBAR_LIBRARY_H */
