@@ -22,6 +22,7 @@
 
 #include "library.h"
 
+
 gint
 ar_asprintf(gchar **string, const gchar *format,...)
 {
@@ -31,53 +32,70 @@ ar_asprintf(gchar **string, const gchar *format,...)
 	va_start(list, format);
 	return_value = g_vasprintf(string, format, list);
 	va_end(list);
-
+#ifdef DEBUG
 	ARASSERT(return_value != -1);
+#endif /* DEBUG */
 
 	return return_value;
 }
 
 static gint
-get_last_space(const gchar * text, gint length)
+get_last_space(const gchar * text)
 {
 	gint i;
+	gint length;
 
+	length=strlen(text);
 	for(i = 0; (i < length) && (*(text+length-i) != ' '); i++);
 
 	return length - i;
 }
 
+static void
+substitute_char(gchar ** formatted, gint i)
+{
+	if ((*formatted)[i] == '_')
+		(*formatted)[i]=' ';
+	/* This substitution is needed for constructing ACE
+	 * commands on drag & drop.  */
+	if ((*formatted)[i] == '@')
+		(*formatted)[i]='_';
+
+}
+
 static void
 substitute(gchar **formatted, gint length)
 {
 	gint i;
 
 	for (i = 0; i < length; i++)
-	{
-		if ((*formatted)[i] == '_')
-			(*formatted)[i]=' ';
-		/* This substitution is needed for constructing ACE
-		 * commands on drag & drop.  */
-		if ((*formatted)[i] == '@')
-			(*formatted)[i]='_';
-	}
+		substitute_char(formatted, i);
 
 	/* Ensure that the string is null-terminated.  */
 	(*formatted)[i]='\0';
 }
 
-/* Free the returned value!  */
-char *
-antiright_beautified_label(char *text)
+static char *
+get_substituted_label_from_text(const gchar * text)
 {
-	gint length;
-	gchar *formatted;
+	gchar * formatted;
 
-	length=strlen(text);
-	text += get_last_space(text, length);
-	length=ar_asprintf(&formatted, "%s", text);
-	substitute(&formatted, length);
+	{
+		gint length;
+
+		length=ar_asprintf(&formatted, "%s", text);
+		substitute(&formatted, length);
+	}
 
 	return (formatted);
 }
 
+/* Free the returned value!  */
+char *
+antiright_beautified_label(const gchar *text)
+{
+	text += get_last_space(text);
+
+	return get_substituted_label_from_text(text);
+}
+
